==> haskell-hspec-contrib-0.5.0-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-CvLchkNmcHJ9hT1Fw3zdoe
key: hspec-contrib-0.5.0-CvLchkNmcHJ9hT1Fw3zdoe
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: 63759b2d1955b93e6c6e36001bc2c1a0
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-CvLchkNmcHJ9hT1Fw3zdoe
depends:
    base-4.11.1.0 hspec-core-2.5.5-JkTBo1rg7HTBOLULl3f0b6
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hspec-core-2.5.5-JkTBo1rg7HTBOLULl3f0b6=63a29cd1d27d2be3961bef1ab5c0ca74
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.0-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-HDPu1mCmmXh75dDDkh11nv
key: hspec-contrib-0.5.0-HDPu1mCmmXh75dDDkh11nv
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: e6ad59d3d91c29239df5b4b4b3e2f1b7
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-HDPu1mCmmXh75dDDkh11nv
depends:
    base-4.11.1.0 hspec-core-2.5.5-2zCVm1xYPFGACNFYwa6CSe
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hspec-core-2.5.5-2zCVm1xYPFGACNFYwa6CSe=50314e5fd95507e182f90af4a0fe2345
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
